@@ -1,19 +1,8 @@
-/* This file is part of the KDE libraries
-   Copyright (C) 2005 Olivier Goffart <ogoffart at kde.org>
+/*
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2005 Olivier Goffart <ogoffart at kde.org>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "knotifyconfigwidget.h"
@@ -24,10 +13,9 @@
 #include <QDialog>
 #include <QDialogButtonBox>
 #include <QVBoxLayout>
-#include <QDBusInterface>
 #include <QDBusConnectionInterface>
 
-#include <klocalizedstring.h>
+#include <KLocalizedString>
 
 class KNotifyConfigWidgetPrivate {
 public:
@@ -42,7 +30,7 @@ public:
 KNotifyConfigWidget::KNotifyConfigWidget(QWidget *parent)
     : QWidget(parent), d(new KNotifyConfigWidgetPrivate)
 {
-    d->currentElement = 0l;
+    d->currentElement = nullptr;
     d->eventList = new KNotifyEventList(this);
     d->eventList->setFocus();
     d->actionsconfig = new KNotifyConfigActionsWidget(this);
@@ -52,7 +40,7 @@ KNotifyConfigWidget::KNotifyConfigWidget(QWidget *parent)
     connect(d->actionsconfig, SIGNAL(changed()), this, SLOT(slotActionChanged()));
 
     QVBoxLayout *layout = new QVBoxLayout(this);
-    layout->setMargin(0);
+    layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(d->eventList, 1);
     layout->addWidget(d->actionsconfig);
 }
@@ -64,7 +52,7 @@ KNotifyConfigWidget::~KNotifyConfigWidget()
 
 void KNotifyConfigWidget::setApplication(const QString &app, const QString &context_name, const QString &context_value)
 {
-    d->currentElement = 0l;
+    d->currentElement = nullptr;
     d->application = app.isEmpty() ? QCoreApplication::instance()->applicationName()  : app;
     d->contextName = context_name;
     d->contextValue = context_value;
@@ -101,7 +89,7 @@ void KNotifyConfigWidget::save()
     emit changed(false);
 
     //ask KNotification objects to reload their config
-    QDBusMessage message = QDBusMessage::createSignal("/Config", "org.kde.knotification", "reparseConfiguration");
+    QDBusMessage message = QDBusMessage::createSignal(QStringLiteral("/Config"), QStringLiteral("org.kde.knotification"), QStringLiteral("reparseConfiguration"));
     message.setArguments(QVariantList() << d->application);
     QDBusConnection::sessionBus().send(message);
 }
